==> adwaita-icon-theme-3.28.0-noarch-2.txz: install/doinst.sh <==
if [ -e /usr/share/icons/Adwaita/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache /usr/share/icons/Adwaita 1> /dev/null 2> /dev/null
  fi
fi

( cd usr/share/icons/Adwaita/cursors ; rm -rf grab )
( cd usr/share/icons/Adwaita/cursors ; ln -sf hand1 grab )
( cd usr/share/icons/Adwaita/cursors ; rm -rf size_bdiag )
( cd usr/share/icons/Adwaita/cursors ; ln -sf fd_double_arrow size_bdiag )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 6407b0e94181790501fd1e167b474872 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf copy 6407b0e94181790501fd1e167b474872 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf e-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf right_side e-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf draft_large )
( cd usr/share/icons/Adwaita/cursors ; ln -sf right_ptr draft_large )
( cd usr/share/icons/Adwaita/cursors ; rm -rf icon )
( cd usr/share/icons/Adwaita/cursors ; ln -sf dotbox icon )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 4498f0e0c1937ffe01fd06f973665830 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf move 4498f0e0c1937ffe01fd06f973665830 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf left_ptr_help )
( cd usr/share/icons/Adwaita/cursors ; ln -sf question_arrow left_ptr_help )
( cd usr/share/icons/Adwaita/cursors ; rm -rf ne-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf top_right_corner ne-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf hand )
( cd usr/share/icons/Adwaita/cursors ; ln -sf hand2 hand )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_left_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf left_ptr top_left_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf progress )
( cd usr/share/icons/Adwaita/cursors ; ln -sf left_ptr_watch progress )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 9081237383d90e509aa00f00170e968f )
( cd usr/share/icons/Adwaita/cursors ; ln -sf move 9081237383d90e509aa00f00170e968f )
( cd usr/share/icons/Adwaita/cursors ; rm -rf not-allowed )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crossed_circle not-allowed )
( cd usr/share/icons/Adwaita/cursors ; rm -rf size_all )
( cd usr/share/icons/Adwaita/cursors ; ln -sf fleur size_all )
( cd usr/share/icons/Adwaita/cursors ; rm -rf pirate )
( cd usr/share/icons/Adwaita/cursors ; ln -sf X_cursor pirate )
( cd usr/share/icons/Adwaita/cursors ; rm -rf arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf left_ptr arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 9d800788f1b08800ae810202380a0822 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf hand2 9d800788f1b08800ae810202380a0822 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf no-drop )
( cd usr/share/icons/Adwaita/cursors ; ln -sf dnd-no-drop no-drop )
( cd usr/share/icons/Adwaita/cursors ; rm -rf h_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_h_double_arrow h_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf s-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf bottom_side s-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 00008160000006810000408080010102 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf v_double_arrow 00008160000006810000408080010102 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 3085a0e285430894940527032f8b26df )
( cd usr/share/icons/Adwaita/cursors ; ln -sf link 3085a0e285430894940527032f8b26df )
( cd usr/share/icons/Adwaita/cursors ; rm -rf default )
( cd usr/share/icons/Adwaita/cursors ; ln -sf left_ptr default )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 03b6e0fcb3499374a867c041f52298f0 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crossed_circle 03b6e0fcb3499374a867c041f52298f0 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 14fef782d02440884392942c11205230 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_h_double_arrow 14fef782d02440884392942c11205230 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf cross_reverse )
( cd usr/share/icons/Adwaita/cursors ; ln -sf cross cross_reverse )
( cd usr/share/icons/Adwaita/cursors ; rm -rf draped_box )
( cd usr/share/icons/Adwaita/cursors ; ln -sf dotbox draped_box )
( cd usr/share/icons/Adwaita/cursors ; rm -rf size_fdiag )
( cd usr/share/icons/Adwaita/cursors ; ln -sf bd_double_arrow size_fdiag )
( cd usr/share/icons/Adwaita/cursors ; rm -rf nw-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf top_left_corner nw-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 1081e37283d90000800003c07f3ef6bf )
( cd usr/share/icons/Adwaita/cursors ; ln -sf copy 1081e37283d90000800003c07f3ef6bf )
( cd usr/share/icons/Adwaita/cursors ; rm -rf pointer )
( cd usr/share/icons/Adwaita/cursors ; ln -sf hand pointer )
( cd usr/share/icons/Adwaita/cursors ; rm -rf draft_small )
( cd usr/share/icons/Adwaita/cursors ; ln -sf right_ptr draft_small )
( cd usr/share/icons/Adwaita/cursors ; rm -rf nwse-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf bd_double_arrow nwse-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 2870a09082c103050810ffdffffe0204 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_v_double_arrow 2870a09082c103050810ffdffffe0204 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf fleur )
( cd usr/share/icons/Adwaita/cursors ; ln -sf grabbing fleur )
( cd usr/share/icons/Adwaita/cursors ; rm -rf se-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf bottom_right_corner se-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_v_double_arrow double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 08e8e1c95fe2fc01f976f1e063a24ccd )
( cd usr/share/icons/Adwaita/cursors ; ln -sf left_ptr_watch 08e8e1c95fe2fc01f976f1e063a24ccd )
( cd usr/share/icons/Adwaita/cursors ; rm -rf col-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_h_double_arrow col-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf crosshair )
( cd usr/share/icons/Adwaita/cursors ; ln -sf cross crosshair )
( cd usr/share/icons/Adwaita/cursors ; rm -rf size_hor )
( cd usr/share/icons/Adwaita/cursors ; ln -sf h_double_arrow size_hor )
( cd usr/share/icons/Adwaita/cursors ; rm -rf help )
( cd usr/share/icons/Adwaita/cursors ; ln -sf question_arrow help )
( cd usr/share/icons/Adwaita/cursors ; rm -rf ns-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_v_double_arrow ns-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 028006030e0e7ebffc7f7070c0600140 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf h_double_arrow 028006030e0e7ebffc7f7070c0600140 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf v_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_v_double_arrow v_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf fcf1c3c7cd4491d801f1e1c78f100000 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf fd_double_arrow fcf1c3c7cd4491d801f1e1c78f100000 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 640fb0e74195791501fd1ed57b41487f )
( cd usr/share/icons/Adwaita/cursors ; ln -sf link 640fb0e74195791501fd1ed57b41487f )
( cd usr/share/icons/Adwaita/cursors ; rm -rf sw-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf bottom_left_corner sw-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf d9ce0ab605698f320427677b458ad60b )
( cd usr/share/icons/Adwaita/cursors ; ln -sf question_arrow d9ce0ab605698f320427677b458ad60b )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 3ecb610c1bf2410f44200f48c40d3599 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf left_ptr_watch 3ecb610c1bf2410f44200f48c40d3599 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf nesw-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf fd_double_arrow nesw-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf c7088f0f3e6c8088236ef8e1e3e70000 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf bd_double_arrow c7088f0f3e6c8088236ef8e1e3e70000 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf text )
( cd usr/share/icons/Adwaita/cursors ; ln -sf xterm text )
( cd usr/share/icons/Adwaita/cursors ; rm -rf alias )
( cd usr/share/icons/Adwaita/cursors ; ln -sf dnd-link alias )
( cd usr/share/icons/Adwaita/cursors ; rm -rf copy )
( cd usr/share/icons/Adwaita/cursors ; ln -sf dnd-copy copy )
( cd usr/share/icons/Adwaita/cursors ; rm -rf wait )
( cd usr/share/icons/Adwaita/cursors ; ln -sf watch wait )
( cd usr/share/icons/Adwaita/cursors ; rm -rf ew-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_h_double_arrow ew-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf row-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_v_double_arrow row-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf diamond_cross )
( cd usr/share/icons/Adwaita/cursors ; ln -sf cross diamond_cross )
( cd usr/share/icons/Adwaita/cursors ; rm -rf target )
( cd usr/share/icons/Adwaita/cursors ; ln -sf dotbox target )
( cd usr/share/icons/Adwaita/cursors ; rm -rf n-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf top_side n-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf e29285e634086352946a0e7090d73106 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf hand2 e29285e634086352946a0e7090d73106 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf size_ver )
( cd usr/share/icons/Adwaita/cursors ; ln -sf v_double_arrow size_ver )
( cd usr/share/icons/Adwaita/cursors ; rm -rf w-resize )
( cd usr/share/icons/Adwaita/cursors ; ln -sf left_side w-resize )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 5c6cd98b3f3ebcb1f9c7f1c204630408 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf question_arrow 5c6cd98b3f3ebcb1f9c7f1c204630408 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf dot_box_mask )
( cd usr/share/icons/Adwaita/cursors ; ln -sf dotbox dot_box_mask )

==> adwaita-icon-theme-46.0-noarch-2.txz: install/doinst.sh <==
if [ -e /usr/share/icons/Adwaita/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache /usr/share/icons/Adwaita 1> /dev/null 2> /dev/null
  fi
fi

( cd usr/share/icons/Adwaita/cursors ; rm -rf 00008160000006810000408080010102 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf v_double_arrow 00008160000006810000408080010102 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 028006030e0e7ebffc7f7070c0600140 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf h_double_arrow 028006030e0e7ebffc7f7070c0600140 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 03b6e0fcb3499374a867c041f52298f0 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crossed_circle 03b6e0fcb3499374a867c041f52298f0 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 08e8e1c95fe2fc01f976f1e063a24ccd )
( cd usr/share/icons/Adwaita/cursors ; ln -sf left_ptr_watch 08e8e1c95fe2fc01f976f1e063a24ccd )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 1081e37283d90000800003c07f3ef6bf )
( cd usr/share/icons/Adwaita/cursors ; ln -sf copy 1081e37283d90000800003c07f3ef6bf )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 14fef782d02440884392942c11205230 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_h_double_arrow 14fef782d02440884392942c11205230 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 2870a09082c103050810ffdffffe0204 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_v_double_arrow 2870a09082c103050810ffdffffe0204 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 3085a0e285430894940527032f8b26df )
( cd usr/share/icons/Adwaita/cursors ; ln -sf link 3085a0e285430894940527032f8b26df )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 3ecb610c1bf2410f44200f48c40d3599 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf left_ptr_watch 3ecb610c1bf2410f44200f48c40d3599 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 4498f0e0c1937ffe01fd06f973665830 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf move 4498f0e0c1937ffe01fd06f973665830 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 5c6cd98b3f3ebcb1f9c7f1c204630408 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf question_arrow 5c6cd98b3f3ebcb1f9c7f1c204630408 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 6407b0e94181790501fd1e167b474872 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf copy 6407b0e94181790501fd1e167b474872 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 640fb0e74195791501fd1ed57b41487f )
( cd usr/share/icons/Adwaita/cursors ; ln -sf link 640fb0e74195791501fd1ed57b41487f )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 9081237383d90e509aa00f00170e968f )
( cd usr/share/icons/Adwaita/cursors ; ln -sf move 9081237383d90e509aa00f00170e968f )
( cd usr/share/icons/Adwaita/cursors ; rm -rf 9d800788f1b08800ae810202380a0822 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf hand2 9d800788f1b08800ae810202380a0822 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf nwse-resize bd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bottom_left_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sw-resize bottom_left_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bottom_right_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf se-resize bottom_right_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bottom_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf s-resize bottom_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf c7088f0f3e6c8088236ef8e1e3e70000 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf bd_double_arrow c7088f0f3e6c8088236ef8e1e3e70000 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf cross )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair cross )
( cd usr/share/icons/Adwaita/cursors ; rm -rf cross_reverse )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair cross_reverse )
( cd usr/share/icons/Adwaita/cursors ; rm -rf d9ce0ab605698f320427677b458ad60b )
( cd usr/share/icons/Adwaita/cursors ; ln -sf question_arrow d9ce0ab605698f320427677b458ad60b )
( cd usr/share/icons/Adwaita/cursors ; rm -rf diamond_cross )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair diamond_cross )
( cd usr/share/icons/Adwaita/cursors ; rm -rf dot_box_mask )
( cd usr/share/icons/Adwaita/cursors ; ln -sf dotbox dot_box_mask )
( cd usr/share/icons/Adwaita/cursors ; rm -rf double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_v_double_arrow double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf draft_large )
( cd usr/share/icons/Adwaita/cursors ; ln -sf right_ptr draft_large )
( cd usr/share/icons/Adwaita/cursors ; rm -rf draft_small )
( cd usr/share/icons/Adwaita/cursors ; ln -sf right_ptr draft_small )
( cd usr/share/icons/Adwaita/cursors ; rm -rf draped_box )
( cd usr/share/icons/Adwaita/cursors ; ln -sf dotbox draped_box )
( cd usr/share/icons/Adwaita/cursors ; rm -rf e29285e634086352946a0e7090d73106 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf hand2 e29285e634086352946a0e7090d73106 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf fcf1c3c7cd4491d801f1e1c78f100000 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf fd_double_arrow fcf1c3c7cd4491d801f1e1c78f100000 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf fd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf nesw-resize fd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf fleur )
( cd usr/share/icons/Adwaita/cursors ; ln -sf move fleur )
( cd usr/share/icons/Adwaita/cursors ; rm -rf h_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_h_double_arrow h_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf hand )
( cd usr/share/icons/Adwaita/cursors ; ln -sf hand2 hand )
( cd usr/share/icons/Adwaita/cursors ; rm -rf hand1 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf grab hand1 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf hand2 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf pointer hand2 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf icon )
( cd usr/share/icons/Adwaita/cursors ; ln -sf dotbox icon )
( cd usr/share/icons/Adwaita/cursors ; rm -rf left_ptr )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default left_ptr )
( cd usr/share/icons/Adwaita/cursors ; rm -rf left_ptr_help )
( cd usr/share/icons/Adwaita/cursors ; ln -sf question_arrow left_ptr_help )
( cd usr/share/icons/Adwaita/cursors ; rm -rf left_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf w-resize left_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf pirate )
( cd usr/share/icons/Adwaita/cursors ; ln -sf X_cursor pirate )
( cd usr/share/icons/Adwaita/cursors ; rm -rf question_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf help question_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf right_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf e-resize right_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf sb_h_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf ew-resize sb_h_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf sb_v_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf ns-resize sb_v_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf size_all )
( cd usr/share/icons/Adwaita/cursors ; ln -sf fleur size_all )
( cd usr/share/icons/Adwaita/cursors ; rm -rf size_bdiag )
( cd usr/share/icons/Adwaita/cursors ; ln -sf fd_double_arrow size_bdiag )
( cd usr/share/icons/Adwaita/cursors ; rm -rf size_fdiag )
( cd usr/share/icons/Adwaita/cursors ; ln -sf bd_double_arrow size_fdiag )
( cd usr/share/icons/Adwaita/cursors ; rm -rf size_hor )
( cd usr/share/icons/Adwaita/cursors ; ln -sf h_double_arrow size_hor )
( cd usr/share/icons/Adwaita/cursors ; rm -rf size_ver )
( cd usr/share/icons/Adwaita/cursors ; ln -sf v_double_arrow size_ver )
( cd usr/share/icons/Adwaita/cursors ; rm -rf target )
( cd usr/share/icons/Adwaita/cursors ; ln -sf dotbox target )
( cd usr/share/icons/Adwaita/cursors ; rm -rf tcross )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair tcross )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_left_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default top_left_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_left_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf nw-resize top_left_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_right_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf ne-resize top_right_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf n-resize top_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf v_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sb_v_double_arrow v_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf watch )
( cd usr/share/icons/Adwaita/cursors ; ln -sf wait watch )
( cd usr/share/icons/Adwaita/cursors ; rm -rf xterm )
( cd usr/share/icons/Adwaita/cursors ; ln -sf text xterm )
